ref: ff2d8502197934e07a45903102560e8eb81d2b5b
parent: d9603e3e331655bb7e061b612730b68cd4378f96
author: Rangi <remy.oukaour+rangi42@gmail.com>
date: Mon Oct 5 07:24:47 EDT 2020
Identify some more unnamed labels
--- a/audio/sfx.asm
+++ b/audio/sfx.asm
@@ -1492,9 +1492,9 @@
toggle_sfx
sfx_toggle_noise 3
drum_speed 8
-Sfx_2ndPlace_branch_f0fd7:
+.loop1:
note C#, 1
- sound_loop 6, Sfx_2ndPlace_branch_f0fd7
+ sound_loop 6, .loop1
note B_, 12
note B_, 12
note B_, 12
@@ -1889,10 +1889,10 @@
note_type 6, 9, 2
octave 4
note F_, 3
- sound_call Sfx_GetBadge_branch_f11aa
+ sound_call .sub1
note A#, 3
transpose 0, 2
- sound_call Sfx_GetBadge_branch_f11aa
+ sound_call .sub1
transpose 0, 0
volume_envelope 10, 7
note A_, 16
@@ -1901,7 +1901,7 @@
toggle_sfx ; unused
-Sfx_GetBadge_branch_f11aa:
+.sub1:
rest 5
octave 3
note F_, 2
@@ -2015,7 +2015,7 @@
toggle_sfx
sfx_toggle_noise 4
drum_speed 6
-Sfx_GetBadge_branch_f1220:
+.loop1:
note B_, 12
note D_, 1
note D_, 1
@@ -2030,7 +2030,7 @@
note C#, 1
note C#, 1
note C#, 1
- sound_loop 2, Sfx_GetBadge_branch_f1220
+ sound_loop 2, .loop1
note B_, 16
rest 6
sound_ret
@@ -2163,7 +2163,7 @@
toggle_sfx
note_type 1, 15, 1
duty_cycle 0
-Sfx_Protect_branch_f12c0:
+.loop1:
octave 5
note F_, 5
note A_, 5
@@ -2176,7 +2176,7 @@
octave 6
note C#, 5
note E_, 5
- sound_loop 3, Sfx_Protect_branch_f12c0
+ sound_loop 3, .loop1
volume_envelope 12, 1
octave 5
note F_, 5
@@ -2210,12 +2210,12 @@
Sfx_Sketch_Ch5:
duty_cycle 1
pitch_sweep 10, 5
-Sfx_Sketch_branch_f12fd:
+.loop1:
square_note 2, 15, 1, 1760
square_note 13, 10, -7, 1456
square_note 4, 0, 0, 0
square_note 9, 15, 4, 1816
- sound_loop 3, Sfx_Sketch_branch_f12fd
+ sound_loop 3, .loop1
pitch_sweep 0, 8
sound_ret
@@ -2392,7 +2392,7 @@
Sfx_Nightmare_Ch5:
duty_cycle 0
pitch_sweep 3, 4
-Sfx_Nightmare_branch_f1424:
+.loop1:
square_note 3, 11, -2, 1585
square_note 2, 0, 0, 0
square_note 3, 15, 8, 1569
@@ -2403,7 +2403,7 @@
square_note 2, 0, 0, 0
square_note 3, 14, 8, 1521
square_note 2, 0, 0, 0
- sound_loop 2, Sfx_Nightmare_branch_f1424
+ sound_loop 2, .loop1
pitch_sweep 0, 8
sound_ret
@@ -2426,10 +2426,10 @@
Sfx_SweetKiss_Ch5:
duty_cycle 2
-Sfx_SweetKiss_branch_f146e:
+.loop1:
square_note 2, 12, 1, 1992
square_note 2, 13, 1, 2010
- sound_loop 2, Sfx_SweetKiss_branch_f146e
+ sound_loop 2, .loop1
square_note 26, 15, 1, 2018
sound_ret
@@ -2657,10 +2657,10 @@
pitch_sweep 7, 7
duty_cycle 3
square_note 2, 15, 8, 1824
-Sfx_MeanLook_branch_f15fa:
+.loop1:
square_note 1, 8, 8, 1632
square_note 2, 15, 8, 1936
- sound_loop 5, Sfx_MeanLook_branch_f15fa
+ sound_loop 5, .loop1
square_note 12, 15, 8, 1792
square_note 12, 12, 8, 1824
square_note 12, 10, 8, 1792
@@ -2688,13 +2688,13 @@
Sfx_Return_Ch5:
duty_cycle 0
-Sfx_Return_branch_f163c:
+.loop1:
pitch_sweep 11, -7
square_note 8, 15, 1, 1881
pitch_sweep 5, 7
square_note 8, 15, 1, 1881
square_note 16, 0, 0, 0
- sound_loop 2, Sfx_Return_branch_f163c
+ sound_loop 2, .loop1
pitch_sweep 0, 8
sound_ret
@@ -2723,7 +2723,7 @@
Sfx_MilkDrink_Ch5:
duty_cycle 2
-Sfx_MilkDrink_branch_f1684:
+.loop1:
pitch_sweep 10, 4
square_note 2, 14, -2, 1248
square_note 13, 15, 7, 656
@@ -2730,7 +2730,7 @@
pitch_sweep 9, -6
square_note 4, 12, -1, 1505
square_note 2, 0, 0, 0
- sound_loop 6, Sfx_MilkDrink_branch_f1684
+ sound_loop 6, .loop1
pitch_sweep 0, 8
sound_ret
@@ -2741,10 +2741,10 @@
Sfx_Present_Ch5:
duty_cycle 2
pitch_sweep 13, 6
-Sfx_Present_branch_f16a6:
+.loop1:
square_note 2, 15, 1, 1856
square_note 1, 0, 0, 0
- sound_loop 3, Sfx_Present_branch_f16a6
+ sound_loop 3, .loop1
square_note 16, 15, 1, 1920
pitch_sweep 0, 8
sound_ret
@@ -2755,11 +2755,11 @@
Sfx_MorningSun_Ch5:
duty_cycle 3
-Sfx_MorningSun_branch_f16be:
+.loop1:
square_note 2, 15, 1, 2020
square_note 2, 15, 1, 2016
square_note 5, 15, 2, 2023
- sound_loop 3, Sfx_MorningSun_branch_f16be
+ sound_loop 3, .loop1
square_note 1, 0, 0, 0
square_note 8, 12, 2, 2023
square_note 1, 0, 0, 0
@@ -2772,10 +2772,10 @@
Sfx_Moonlight_Ch5:
duty_cycle 2
-Sfx_Moonlight_branch_f16e4:
+.loop1:
square_note 1, 15, 8, 2000
square_note 4, 15, 1, 2016
- sound_loop 2, Sfx_Moonlight_branch_f16e4
+ sound_loop 2, .loop1
square_note 16, 15, 1, 2016
square_note 16, 13, 1, 2016
square_note 16, 8, 1, 2016
@@ -2790,10 +2790,10 @@
duty_cycle 2
pitch_sweep 12, -6
square_note 16, 0, 0, 0
-Sfx_Encore_branch_f170b:
+.loop1:
square_note 2, 15, 8, 1908
square_note 36, 0, 0, 0
- sound_loop 2, Sfx_Encore_branch_f170b
+ sound_loop 2, .loop1
pitch_sweep 0, 8
sound_ret
@@ -2951,12 +2951,12 @@
Sfx_GsIntroCharizardFireball_Ch8:
noise_note 8, 12, -7, 77
noise_note 8, 15, 1, 55
-Sfx_GsIntroCharizardFireball_branch_f17e2:
+.loop1:
noise_note 1, 15, 8, 79
noise_note 0, 12, 8, 38
noise_note 1, 13, 8, 95
noise_note 0, 10, 8, 55
- sound_loop 12, Sfx_GsIntroCharizardFireball_branch_f17e2
+ sound_loop 12, .loop1
noise_note 3, 15, 8, 111
noise_note 4, 13, 8, 95
noise_note 12, 13, 8, 92
@@ -3203,13 +3203,13 @@
sfx_toggle_noise 4
drum_speed 12
note C_, 4
-Sfx_DexFanfare140169_branch_f1945:
+.loop1:
note D_, 4
note C#, 1
note C#, 1
note C#, 1
note C#, 1
- sound_loop 3, Sfx_DexFanfare140169_branch_f1945
+ sound_loop 3, .loop1
note D_, 8
sound_ret
@@ -3605,7 +3605,7 @@
note D_, 2
note D_, 2
note D_, 2
-Sfx_DexFanfare230Plus_branch_f1b14:
+.loop1:
note D_, 6
note D_, 2
note D_, 2
@@ -3617,7 +3617,7 @@
note C#, 1
note C#, 1
note C#, 1
- sound_loop 2, Sfx_DexFanfare230Plus_branch_f1b14
+ sound_loop 2, .loop1
note D_, 6
note D_, 2
note D_, 2
@@ -3626,9 +3626,9 @@
note D_, 4
note D_, 4
note D_, 4
-Sfx_DexFanfare230Plus_branch_f1b2b:
+.loop2:
note C#, 1
- sound_loop 18, Sfx_DexFanfare230Plus_branch_f1b2b
+ sound_loop 18, .loop2
note D_, 6
sound_ret
@@ -3714,11 +3714,11 @@
Sfx_SweetScent2_Ch8:
noise_note 2, 14, 8, 34
noise_note 17, 10, -2, 0
-Sfx_SweetScent2_branch_f1bd2:
+.loop1:
noise_note 4, 13, -1, 16
noise_note 8, 9, 1, 0
noise_note 2, 6, 1, 7
- sound_loop 5, Sfx_SweetScent2_branch_f1bd2
+ sound_loop 5, .loop1
noise_note 4, 9, -1, 0
noise_note 10, 6, 1, 0
noise_note 6, 5, -1, 0
@@ -3819,13 +3819,13 @@
Sfx_2Boops_Ch5:
duty_cycle 2
-Sfx_2Boops_branch_f1cb9:
+.loop1:
pitch_sweep 7, -1
square_note 1, 9, -1, 1379
square_note 4, 15, 2, 1205
pitch_sweep 4, 3
square_note 16, 15, 8, 1485
- sound_loop 2, Sfx_2Boops_branch_f1cb9
+ sound_loop 2, .loop1
pitch_sweep 0, 8
sound_ret
--- a/engine/battle/menu.asm
+++ b/engine/battle/menu.asm
@@ -11,15 +11,15 @@
SafariBattleMenu:
; untranslated
- ld hl, MenuHeader_0x24f4e
+ ld hl, SafariBattleMenuHeader
call LoadMenuHeader
- jr Function24f19
+ jr CommonBattleMenu
ContestBattleMenu:
- ld hl, MenuHeader_0x24f89
+ ld hl, ContestBattleMenuHeader
call LoadMenuHeader
-
-Function24f19:
+; fallthrough
+CommonBattleMenu:
ld a, [wBattleMenuCursorBuffer]
ld [wMenuCursorBuffer], a
call _2DMenu
@@ -31,42 +31,42 @@
BattleMenuHeader:
db MENU_BACKUP_TILES ; flags
menu_coords 8, 12, SCREEN_WIDTH - 1, SCREEN_HEIGHT - 1
- dw MenuData_0x24f34
+ dw .MenuData
db 1 ; default option
-MenuData_0x24f34:
+.MenuData:
db STATICMENU_CURSOR | STATICMENU_DISABLE_B ; flags
dn 2, 2 ; rows, columns
db 6 ; spacing
- dba Strings24f3d
- dbw BANK(MenuData_0x24f34), 0
+ dba .Text
+ dbw BANK(@), NULL
-Strings24f3d:
+.Text:
db "FIGHT@"
db "<PKMN>@"
db "PACK@"
db "RUN@"
-MenuHeader_0x24f4e:
+SafariBattleMenuHeader:
db MENU_BACKUP_TILES ; flags
menu_coords 0, 12, SCREEN_WIDTH - 1, SCREEN_HEIGHT - 1
- dw MenuData_0x24f56
+ dw .MenuData
db 1 ; default option
-MenuData_0x24f56:
+.MenuData:
db STATICMENU_CURSOR | STATICMENU_DISABLE_B ; flags
dn 2, 2 ; rows, columns
db 11 ; spacing
- dba Strings24f5f
- dba Function24f7c
+ dba .Text
+ dba .PrintSafariBallsRemaining
-Strings24f5f:
+.Text:
db "サファりボール× @" ; "SAFARI BALL× @"
db "エサをなげる@" ; "THROW BAIT"
db "いしをなげる@" ; "THROW ROCK"
db "にげる@" ; "RUN"
-Function24f7c:
+.PrintSafariBallsRemaining:
hlcoord 17, 13
ld de, wSafariBallsRemaining
lb bc, PRINTNUM_LEADINGZEROS | 1, 2
@@ -73,26 +73,26 @@
call PrintNum
ret
-MenuHeader_0x24f89:
+ContestBattleMenuHeader:
db MENU_BACKUP_TILES ; flags
menu_coords 2, 12, SCREEN_WIDTH - 1, SCREEN_HEIGHT - 1
- dw MenuData_0x24f91
+ dw .MenuData
db 1 ; default option
-MenuData_0x24f91:
+.MenuData:
db STATICMENU_CURSOR | STATICMENU_DISABLE_B ; flags
dn 2, 2 ; rows, columns
db 12 ; spacing
- dba Strings24f9a
- dba Function24fb2
+ dba .Text
+ dba .PrintParkBallsRemaining
-Strings24f9a:
+.Text:
db "FIGHT@"
db "<PKMN>@"
db "PARKBALL× @"
db "RUN@"
-Function24fb2:
+.PrintParkBallsRemaining:
hlcoord 13, 16
ld de, wParkBallsRemaining
lb bc, PRINTNUM_LEADINGZEROS | 1, 2
--- a/engine/overworld/npc_movement.asm
+++ b/engine/overworld/npc_movement.asm
@@ -58,7 +58,7 @@
ret
WillObjectBumpIntoWater:
- call Function6f5f
+ call CanObjectLeaveTile
ret c
ld hl, OBJECT_NEXT_MAP_X
add hl, bc
@@ -69,7 +69,7 @@
ld hl, OBJECT_PALETTE
add hl, bc
bit OAM_PRIORITY, [hl]
- jp nz, Function6fa1
+ jp nz, WillObjectRemainOnWater
ld hl, OBJECT_NEXT_TILE
add hl, bc
ld a, [hl]
@@ -81,7 +81,7 @@
ret
WillObjectBumpIntoLand:
- call Function6f5f
+ call CanObjectLeaveTile
ret c
ld hl, OBJECT_NEXT_TILE
add hl, bc
@@ -96,7 +96,7 @@
ld hl, OBJECT_NEXT_TILE
add hl, bc
ld a, [hl]
- call Function6f7f
+ call GetSideWallDirectionMask
ret nc
push af
ld hl, OBJECT_DIRECTION_WALKING
@@ -105,7 +105,7 @@
maskbits NUM_DIRECTIONS
ld e, a
ld d, 0
- ld hl, .data_6f5b
+ ld hl, .dir_masks
add hl, de
pop af
and [hl]
@@ -113,17 +113,17 @@
scf
ret
-.data_6f5b
+.dir_masks
db DOWN_MASK ; DOWN
db UP_MASK ; UP
db RIGHT_MASK ; LEFT
db LEFT_MASK ; RIGHT
-Function6f5f:
+CanObjectLeaveTile:
ld hl, OBJECT_STANDING_TILE
add hl, bc
ld a, [hl]
- call Function6f7f
+ call GetSideWallDirectionMask
ret nc
push af
ld hl, OBJECT_DIRECTION_WALKING
@@ -131,7 +131,7 @@
maskbits NUM_DIRECTIONS
ld e, a
ld d, 0
- ld hl, .data_6f7b
+ ld hl, .dir_masks
add hl, de
pop af
and [hl]
@@ -139,13 +139,13 @@
scf
ret
-.data_6f7b
+.dir_masks
db UP_MASK ; DOWN
db DOWN_MASK ; UP
db LEFT_MASK ; LEFT
db RIGHT_MASK ; RIGHT
-Function6f7f:
+GetSideWallDirectionMask:
ld d, a
and $f0
cp HI_NYBBLE_SIDE_WALLS
@@ -157,16 +157,16 @@
.continue
ld a, d
- and 7
+ and $7
ld e, a
ld d, 0
- ld hl, .data_6f99
+ ld hl, .side_wall_masks
add hl, de
ld a, [hl]
scf
ret
-.data_6f99
+.side_wall_masks
db RIGHT_MASK ; COLL_RIGHT_WALL/BUOY
db LEFT_MASK ; COLL_LEFT_WALL/BUOY
db DOWN_MASK ; COLL_UP_WALL/BUOY
@@ -176,7 +176,7 @@
db DOWN_MASK | RIGHT_MASK ; COLL_UP_RIGHT_WALL/BUOY
db DOWN_MASK | LEFT_MASK ; COLL_UP_LEFT_WALL/BUOY
-Function6fa1:
+WillObjectRemainOnWater:
ld hl, OBJECT_DIRECTION_WALKING
add hl, bc
ld a, [hl]
@@ -231,7 +231,7 @@
; Double the distance for counter tiles.
call CheckCounterTile
- jr nz, .asm_6ff1
+ jr nz, .not_counter
ld a, [wPlayerStandingMapX]
sub d
@@ -247,7 +247,7 @@
add e
ld e, a
-.asm_6ff1
+.not_counter
ld bc, wObjectStructs ; redundant
ld a, 0
ldh [hMapObjectIndexBuffer], a
@@ -328,7 +328,7 @@
bit BIG_OBJECT_F, [hl]
jr z, .got
- call Function7171
+ call WillObjectIntersectBigObject
jr nc, .ok
jr .ok2
@@ -489,7 +489,7 @@
ld a, [hl]
cp SPRITEMOVEDATA_BIGDOLLSYM
jr nz, .not_snorlax
- call Function7171
+ call WillObjectIntersectBigObject
jr c, .yes
jr .next
@@ -538,13 +538,13 @@
scf
ret
-Function7171:
+WillObjectIntersectBigObject:
ld hl, OBJECT_NEXT_MAP_X
add hl, bc
ld a, d
sub [hl]
jr c, .nope
- cp $2
+ cp 2 ; big doll width
jr nc, .nope
ld hl, OBJECT_NEXT_MAP_Y
add hl, bc
@@ -551,7 +551,7 @@
ld a, e
sub [hl]
jr c, .nope
- cp $2
+ cp 2 ; big doll height
jr nc, .nope
scf
ret
--- a/home/serial.asm
+++ b/home/serial.asm
@@ -253,7 +253,7 @@
ld c, 2
ld a, TRUE
ldh [hSerialIgnoringInitialData], a
-.asm_847
+.exchange
call DelayFrame
ld a, [hl]
ldh [hSerialSend], a
@@ -264,12 +264,12 @@
and a
ld a, FALSE
ldh [hSerialIgnoringInitialData], a
- jr nz, .asm_847
+ jr nz, .exchange
ld a, b
ld [de], a
inc de
dec c
- jr nz, .asm_847
+ jr nz, .exchange
ret
Serial_PrintWaitingTextAndSyncAndExchangeNybble::
--- a/maps/EarlsPokemonAcademy.asm
+++ b/maps/EarlsPokemonAcademy.asm
@@ -111,7 +111,7 @@
dn 3, 2 ; rows, columns
db 5 ; spacing
dba .Text
- dbw BANK(AcademyBlackboard), 0
+ dbw BANK(@), NULL
.Text:
db "PSN@"
--- a/engine/battle_anims/functions.asm
+++ b/engine/battle_anims/functions.asm
@@ -864,7 +864,7 @@
ld hl, BATTLEANIMSTRUCT_YOFFSET
add hl, bc
ld [hl], a
- call Functioncd557
+ call BattleAnim_ScatterHorizontal
ld hl, BATTLEANIMSTRUCT_VAR2
add hl, bc
ld a, [hl]
@@ -957,8 +957,8 @@
call BattleAnim_StepToTarget
ret
-Functioncd557:
-; Affects sine movement based on bit 7 of Obj Param
+BattleAnim_ScatterHorizontal:
+; Affects horizontal sine movement based on bit 7 of Obj Param
ld hl, BATTLEANIMSTRUCT_PARAM
add hl, bc
ld a, [hl]
@@ -1043,7 +1043,7 @@
ld hl, BATTLEANIMSTRUCT_YOFFSET
add hl, bc
ld [hl], a
- call Functioncd557
+ call BattleAnim_ScatterHorizontal
ld hl, BATTLEANIMSTRUCT_VAR2
add hl, bc
ld a, [hl]
@@ -1686,7 +1686,7 @@
call BattleAnim_IncAnonJumptableIndex
ld hl, BATTLEANIMSTRUCT_PARAM
add hl, bc
- ld [hl], $0
+ ld [hl], 0
.one
.three
call .GustWobble
@@ -1759,10 +1759,10 @@
add hl, bc
ld a, [hl]
and a
- jr z, .asm_cd9d7
+ jr z, .start_wobble
cp $c2
- jr c, .asm_cd9e2
-.asm_cd9d7
+ jr c, .finish_wobble
+.start_wobble
dec a
ld [hl], a
and $7
@@ -1772,7 +1772,7 @@
inc [hl]
ret
-.asm_cd9e2
+.finish_wobble
xor a
ld hl, BATTLEANIMSTRUCT_VAR2
add hl, bc